# Notes
This guide is up to date as of Sonday Mar 23, 2025.
If changes are made, they will first be made to the guide on [AppleVis](https://www.applevis.com/guides/guide-creating-running-shortcuts-ios-macos)



for iOS 18 and macOS 15

# intro
This guide covers how you can create shortcuts on both macOS and iOS, from automation to creating shortcuts that can enhance your workflow, to turning your shortcuts into .app files on Mac.
## What's a shortcut?
A shortcut is a set of steps (actions) that can be put together to create a workflow, which can do several things at once, such as sending a text to someone and playing a playlist, to sending the last image in your photos to a contact. Other shortcuts can convert things, do location-specific actions, as well as if statements. Shortcuts can also be used to send images and documents to LLMs like ChatGPT.
Shortcuts is very similar to Automator on Mac. In fact, you can import your Automator workflows into Shortcuts.
# Creating your First Shortcut

To create a simple shortcut, do the following:

- Open the Shortcuts app. It should be pre-installed on your device, but if not, you can [get it here](https://apps.apple.com/us/app/shortcuts/id1462947752).
- Once in the main Shortcuts interface, tap the "Shortcuts" tab in the bottom left if on iOS.
- This is a list of all of the shortcuts you have created or added to your device. Tapping one of these will activate it and run the shortcut.
 - You can use the actions rotor to edit the shortcut, or press command+O on Mac.
- Tap the "Create Shortcut" button (command+N on Mac) to begin creating your first shortcut!
## Shortcut Editor
This is the Shortcut Editor, where you add actions to your shortcut.

But first, let's familiarize ourselves with the available buttons in the shortcut editor.

### iOS
#### Top Toolbar

- Unlabeled (button): This button allows you to choose an icon and a color for your shortcut.
- Actions Menu: This brings up a menu with options like Share, Rename, Add to Home Screen, etc.
- Done: Exits the shortcut editor and returns you to the shortcuts tab.

#### Main shortcuts interface
When no actions are added to a shortcut, you will see a search field where you can search for actions.
You will also see your suggested and pinned actions, as well as different categories of actions. Tapping on one of these categories will bring up a list of actions in that category.
Below this is a list of apps you have installed. Each of these apps has its own shortcut actions. Tapping on an app name will show the actions that app has available to it.
#### Bottom Toolbar
- "Undo"/"Redo"
- "Info": Brings up info allowing you to adjust details, privacy settings, or shortcut setup (discussed later).
- "Share": Allows you to share the current shortcut.
- "Run Shortcut": Runs the current shortcut.

### macOS
#### Top Toolbar
- "Edit Icon…": Brings up an interface for editing the icon and color of your shortcut.
- "Shortcut Name": A text box for naming your shortcut.
- "Share": Brings up an interface for sharing your shortcut.
- "Run" (Group): Activate this or the "Play" button within the group to run the shortcut.
- "Action Library"/"Shortcut Details" (Radio Buttons): Controls the visibility of the action library or shortcut details (used for creating keyboard shortcuts, pinning a shortcut in the menu bar, etc.).
#### Main shortcuts interface
The main shortcuts interface consists of the "Actions " List, the search field for searching for actions, a collection containing categories to search by and apps you have installed, and a table containing a list of available actions to add.
Pressing Return on one of the actions will add it to the shortcut.



## Let's Create a Shortcut!
Let's create a simple shortcut with one action: a shortcut that shows a list of the apps you have installed, and will open the selected app.

All shortcuts listed here are available for download.
### [Open App](https://www.icloud.com/shortcuts/947cdb7fb70b4f7aa3b3fb4f08ad1848)
#### Steps to create:
##### iOS
1. Find the search field and search for "Open App".
2. Double tap on the action to add it to the shortcut.
3. Find the action (labeled as "Open, App"), and swipe down to "Edit, App."
  - This is where you could select a specific app. If you want to be asked what app to open, tap with 4 fingers at the bottom of the screen (or use an equivalent gesture) and select "Ask each time". You can also select a variable.
4. Now, in the bottom toolbar, you can tap the "Run Shortcut" button, and see the interface appear.

##### macOS
1. Find the "search text field", and search for "Open App".
2. Navigate to the table and select the Open App action, and then press Enter to add it to the shortcut.
3. Find the Actions list, and interact with the Open App action.
4. Find the "App" button, and activate it to bring up the app picker.
  - You can select for the shortcut to ask you each time next to the apps table.
5. Find the Run button, or press Command+R to run the shortcut.
  - You can stop a shortcut by pressing Command+. (period (full stop)).

#### Notes
- The way to navigate and add actions to a shortcut as shown for this shortcut is the same for all shortcuts and lots of actions, such as selecting a file, folder, etc. to selecting a condition for "If" statements.
- You can use the Actions rotor on iOS, or interact with the name of the action on macOS to change its options.

##### Adding Variables to Actions
In some actions, you can add a variable that has been created, such as Ask for input (see second example below), or a calculation result.
When in a text box for an action, you can add variables from the toolbar right above the keyboard.
Several variables come standard in a shortcut, such as the current contents of the clipboard, or the current date.
A menu or sheet may appear when selecting a variable that will allow you to configure it, such as the date/time format for current date. Several actions can set their own variables, such as the "Ask for Input" action.
- Usually, the next action you add will use the most recent variable. For example, if you add the "Get Clipboard" action, an action to turn on Wi-Fi, and then a "Share" action, the clipboard would be used as the contents to be shared, because the Wi-Fi action does not need or support the clipboard as a possible state (on or off).

## Example Shortcuts
Here is a list of several example shortcuts, as well as the actions used to create them, and how I configure the actions. Most options can be configured by swiping to edit, or selecting "Show more." Variables will be listed in parentheses, (like this). You can press the info button next to any action to find out what it does.
I will list a difficulty rating on how easy or hard I think it is to create the shortcuts listed below. (Note, these difficulty ratings are based on how hard or easy it is to create the shortcut for me. It may be easier or harder depending on your skill level.)


### 1. [Search for Anything](https://www.icloud.com/shortcuts/25cf578e599347f28c21a587a64157c3) (Easy to create. The service is the only thing that needs to be configured.)
#### Description of Shortcut
Gets the provided text, and then shows a list of services to use for searching.
#### Actions in Shortcut
##### 1. Ask for Input:
Ask for, Text, with, What do you want to search for?
##### 2. Search Web.
Search, Ask Each Time (can select a particular service instead), for, (Ask for Input - Variable)



### 2. [Megabytes to Gigabytes](https://www.icloud.com/shortcuts/5a6b6c443c7a430e8fe887c64e7310f6) (slightly harder to create because of variables that need to be manually configured.)
#### Description of shortcut:
Brings up a text box and will convert the number entered (in megabytes), to gigabytes (divides initial number by 1000 to get result).
#### Actions in shortcut
##### 1. Ask for input:
Ask for Number,  with, enter the amount you want to convert to gigabytes.
##### 2. Get Numbers from Input:
Get numbers from, (Ask for Input - variable).
##### 3. Calculate
(Numbers - Variable), divided by, 1000.
##### 4. text:
(Numbers - Variable) MB when converted to gigabytes is  (Calculation Result - Variable) gb.
##### 5. Show alert:
- Message: (Text - Variable).
- Title: "Here's the result:"
- Turn off "Show Cancel Button".

### 3. [Clip View](https://www.icloud.com/shortcuts/5a1e095cbbdd44fa8a69cdc65616e068) (easiest to create. The Quicklook action understands that the clipboard should be shown, no configuration needed other than adding actions.)
#### Description of Shortcut
Gets the current contents of the clipboard and then displays the clipboard in Quicklook for easy sharing/saving.
#### Actions in shortcut:
1. Get clipboard.
2. Quicklook:
Show, (Clipboard - Variable), in Quick Look.


These are just a few examples of shortcuts. Shortcuts can have as many actions as you want, from simple shortcuts with 1 or 2 actions, to [complex shortcuts with over 70 actions for making copying actions easier](https://routinehub.co/shortcut/18369/)
## Moving/rearranging actions
The way to rearrange actions in shortcuts is easy once you know how to do it. It is easier on iOS.
### iOS

- Find the action you want to move.
- On the "Show options menu" button, you can use the actions rotor to get to the direction you wish to move the action in. If moving the action multiple times, it is best to double tap the number of times quickly, otherwise, VoiceOver might lose focus and put you on something else.
### macOS

- To move actions in macOS, first find the action in the list, and root your mouse cursor to the action by pressing VO+Command+F5.
- Press VO+Command+Shift+Space to click and hold the mouse.
- Move to the action you wish to move the dragged action to, then press VO+command+Shift+Space to release the mouse and drop the action.
The action may be placed before or after the currently focused action. If that is the case, move the actions until you get it right. This is why moving actions in iOS is easier, because you can be sure where an action is going to end up.


# Automation
Automation is a way for a shortcut to run when something else happens. Simple examples of things that can be automated include:

- Turning on low power mode when your battery falls below a certain percent.
- Turning on background sounds when you connect to a Bluetooth device.
- turning on/off a light at sunset/sunrise (HomeKit compatible light or other shortcuts enabled accessory required)
- sending a message to someone when you leave/arrive at a location (might be useful for notifying people without an iPhone with Find My about location changes)
- turning on or off a focus mode automatically when something else happens
- and much more.

You can create an automation by doing the following:

1. Open the ShortCuts app and select the "Automations" tab.
2. Select "Add".

Here is a list of triggers that you can use.

- Time of Day: Ex. "At 8:00 a.m., weekdays"
- Alarm: Ex. "When my alarm is stopped"
- Sleep: Ex. "When Wind Down starts"
- Arrive, Ex. "When I arrive at the gym"
- Leave, Ex. " When I leave work"
- Before I Commute, Ex. "15 minutes before I leave for work"
- CarPlay, Ex. "When CarPlay connects"
- Email, Ex. “When I get an email from Jane"
- Message, Ex. “When I get a message from Mom”
- Transaction, Ex. “When I tap a Wallet Card or Pass”
- Apple Watch Workout, Ex. “When I start a workout”
- Wi-Fi, Ex. “When my iPhone joins home Wi-Fi”
- Bluetooth, Ex. “When my iPhone connects to AirPods”
- NFC, Ex. “When I tap an NFC tag”
- App, Ex. “When “Weather” is opened or closed”
- Airplane Mode, Ex. “When Airplane Mode is turned on”
- Low Power Mode, Ex. “When Low Power Mode is turned off”
- Battery Level, Ex. “When battery level rises above 50%”
- Charger, Ex. “When my iPhone connects to power”
- Do Not Disturb, Ex. “When turning Do Not Disturb on” (Triggers   - available for all focus modes you have created)
- Sound Recognition, Ex. “When my iPhone recognizes a doorbell sound”

Home automations will not be covered in this guide.

## Creating a basic automation to turn on low power mode when your battery falls below 10%

- Select the battery level trigger, and press next.
- Set the percent to 10, and select "falls below" and press next.
- Select "New blank automation" 
  - If VO doesn't seem to respond to double tapping the button, try double tapping and holding and then releasing. Alternatively, use explore by touch to find the button, turn off VO, activate the button and then reenable VO. See Accessibility notes at the end of this guide for more details).
- Add "Set Low Power Mode. Configure the action to turn on Low Power Mode by using the actions rotor.
- Press done.
Select run immediately if you want this to happen automatically. Also, you can disable "Notify when run" to not get a notification when the automation runs.

### Notes
Automations are not yet natively supported by macOS as of macOS Sequoia. The "Set Low Power Mode" action does not exist in macOS as of macOS Sequoia.
## Information on automations
If you would rather create a shortcut before setting it up as an automation, you can add the run shortcut action and select a shortcut.
# the Shortcuts Gallery
The shortcuts gallery contains shortcuts built by Apple that you can add. There are several shortcuts you can download, even some basic games, such as "Music Quiz", a game that shuffles your music library and makes you guess the song.
If you want a shortcut, check the gallery for some great shortcuts.
To access the gallery, go to the third tab of the shortcuts app on iOS, or go to the gallery in the top of the first table on macOS.
## Useful links for shortcuts

Here are a few links to get you started with shortcuts beyond the shortcuts in the gallery.
- [https://shortcuts.directory/](Shortcuts.directory)
- [https://shortcutsgallery.com/](ShortcutsGallery.com
- [https://routinehub.co/](routinehub.co/)
- [https://beard.fm/shortcuts](beard.fm/shortcuts)
- [https://matthewcassinelli.com/sirishortcuts/library/](matthewcassinelli.com/sirishortcuts/library)
- [https://www.macstories.net/Shortcuts/](macstories.net/Shortcuts/)
- [https://www.reddit.com/r/shortcuts/](reddit.com/r/shortcuts)

# Using shortcuts in scripts
If you want to have a script run a shortcut, you could run it from the terminal, like this:


``` bash
shortcuts run "MyShortcut"
```


where `"MyShortcut"` is the name of a shortcut.

You can also run shortcuts via AppleScript like this:

``` applescript
tell application "Shortcuts"
    run shortcut named "MyShortcut"
end tell
```

If you want a shortcut to run when you log in, the easiest way is to add it to your dock, and have it open at login.

1. Open the file menu and select "Add to Dock…"
2. The shortcut is now in your dock. Navigate to the dock and you will find your shortcut.
3. Press VO+Shift+M on your shortcut and navigate to the options menu and select "Open at Login".

Adding a shortcut to the dock also adds a .app file that can run the shortcut if opened. Shortcut apps are located in "~/Applications".
# Converting an Automator workflow to a shortcut
I have only tested this with ".workflow" files. This might work with other types of workflow files (quick action, folder action, etc.) created with Automator.
To convert your workflow, do the following:

- Find your workflow file, and press VO+Shift+M.
- Navigate to the "Open with" submenu, and select shortcuts.
- You can press the "Add shortcut" button in the interface that appears to add the shortcut.
- You should see your shortcut with the same name as your workflow. For example, "My Awesome Workflow.workflow" becomes a shortcut named "My Awesome Workflow", with all actions that can be converted to shortcut actions.

# Shortcut Details
On both iOS and macOS, you can view details about a shortcut, as well as privacy settings, and set up questions (not discussed here). I will list the options for both iOS and macOS. You can access the "Shortcut Details" in the top toolbar on macOS, or the info button in the bottom toolbar on iOS.

## iOS
### Details

- Add to Home Screen: Adds the shortcut to your home screen, like an app.
- Show in Share Sheet: Determines if the shortcut can receive input from the share sheet.
- Show on Apple Watch: Determines if the shortcut should be available on Apple Watch.
You may see a message stating "This shortcut uses an action that is not supported on Apple Watch:" followed by the action or actions that cannot work on Apple Watch.
- Pin in Menu Bar: Shows the shortcut in the shortcuts menu bar, accessed via the Menu Extras.
- Receive What’s On Screen: (untested, never used this before) Allows a shortcut to automatically capture and use visible content—like text, images, or links—directly from your screen when the shortcut is run.
- Use as Quick Action: Allows the shortcut to be used as a quick action, allowing the shortcut to receive specified file types.
- There is also an option to open the shortcuts help.

### Privacy

- Allow Running When Locked: Determines if the shortcut can be run while locked. (Some actions require you to unlock your device, such as opening an app, controlling a home accessory, etc.)
- "Allow this shortcut to access" Heading: Shows apps and services that a shortcut is allowed to access.
- Reset Privacy: Resets privacy settings to their defaults. According to the explanatory text, "Resetting this shortcut's privileges will not modify its actions or your data."

## macOS

### Details

The details view is similar on macOS, and contains most of the same actions, except for a few options to show the shortcut as a quick action in the Finder, the Services menu, or on the Touch Bar (if your Mac has one).
You can also add a keyboard shortcut that can be triggered at any time.
### Privacy
Privacy settings are the exact same on macOS as iOS.


## Shortcut Setup
I have never used this before, so I do not know how it works or how to use it.
According to the explainer text, "Questions added here will be asked when this shortcut is imported on a different device. Answers to these questions will be filled into the shortcut."

I believe answers are stored as variables. I have seen examples of shortcuts that have added questions to them, such as [a shortcut to trigger two actions from the action button](https://www.macstories.net/ios/introducing-multibutton-assign-two-shortcuts-to-the-same-action-button-press-on-iphone-15-pro/). In this case, the question gets the shortcut names you wish to run. 

# the many ways to run a shortcut
Now that you have an amazing shortcut, how do you run it?

There are lots of ways to run a shortcut. You can create shortcut widgets to run a particular shortcut, or show several at a time for quick access.

An even quicker way to run a shortcut is to add it to your lock screen if your device supports it.

- Go to the lock screen and authenticate with FaceID, but do not go to the home screen.
- Double tap and hold on the date or time to access lock screen customization.
- Navigate to the lock screen you want to customize using the slider, and press the customize button, then press customize lock screen.
- Find a quick action you wish to remove, remove it, and then tap add quick action.
- In the controls gallery, search or find the shortcut you wish to run. Then, press done.

If you have an iPhone with an action button, you can run a shortcut from the action button by going to Settings>Action Button and using the slider until you get to Shortcut, and then select a shortcut.

You can also assign a VoiceOver gesture or command to a shortcut.

- Open Settings> Accessibility>VoiceOver>Commands
- Press All Commands, and find the Shortcut option.
- Here is a list of every shortcut on your device. (I think the order is semi-random, because I haven't been able to find a distinctive pattern in the list.)
Double tap a shortcut to get the interface for adding a command or gesture to the shortcut.
You can also add shortcuts to Control Center (only in iOS 18).


# Conclusion

Shortcuts is a powerful tool to automate repetitive tasks, streamline workflows, and extend the capabilities of your devices on both iOS and macOS. From building simple one-action shortcuts to creating complex automations triggered by battery level, or even specific apps, shortcuts can greatly simplify your daily routines. With support for importing Automator workflows, and the ability to run shortcuts from scripts, the action button, the lock screen, or VoiceOver gestures, shortcuts can be ran from anywhere, allowing you to get things done easier.


# Accessibility notes and VO Issues
While the majority of shortcuts is accessible (adding/removing actions, rearranging actions, etc), there are some times where text boxes will not show what is in them. You will also not be able to see what you type. Examples of these are in the message field for the "Show Alert" action and the "Show Notification" actions. My best advice is to delete everything if you think you made a mistake. You could also copy/paste the text from another app into the shortcuts app. If the text field disappears for what ever reason, the insertion point will most likely be placed at the beginning of the text. You will have to switch the rotor to characters and swipe down a bunch of times until you get to what you think is the end of the text, and then delete from there. Using something like words or lines will not work.
Keep in mind that you will be hearing the boundary sound, so you will have to use guess work. For example, say the sentence "This is a test" is written, you would have to swipe down 14 times to get to the end.
Manually configuring variables is somewhat confusing if you don't know what you are looking for. If, like me, you think it is inaccessible because everything is dimmed, there is a way to work around this. Actions that can support the variable you are selecting will have a button labeled as the action near them. Pressing this button will select the variable and return you to the main shortcut editor. For example, if you add the "Get current app" action, and then select a variable, you will find a button labeled as "Get current app".

Sometimes, VoiceOver might get stuck at the top of the screen, such as the title of an alert, the prompt of a menu action, etc. You can remedy this by using Explore by Touch to get to the other options, or moving to the end and navigating up.
  - If you try to move to the top of the screen by tapping with 4 fingers, VoiceOver will for some reason go to the dynamic island. You can then (sometimes) swipe past the status bar to the list of controls. Other times, you may have to use explore by touch..

When adding an automation, menu options in the list of shortcuts as well as the new blank automation buttons will most likely not respond to double taps.
The solution is to use a double tap and hold gesture to activate the button.
At one time, a way around this was to scroll up to the top of the page, and then the new blank automation button would work, but an easier option is to just triple tap (if using the default gestures) or double tap and hold. I have not tested the scrolling method, but I have had it work, and then not work on the same iOS version and device.
